@@ -8,20 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_kms._jsii
-import aws_cdk.aws_rds._jsii
-import aws_cdk.aws_secretsmanager._jsii
-import aws_cdk.core._jsii
-import aws_cdk.cx_api._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@pepperize/cdk-serverless-cluster-from-snapshot",
-    "0.0.43",
+    "0.0.45",
     __name__[0:-6],
-    "cdk-serverless-cluster-from-snapshot@0.0.43.jsii.tgz",
+    "cdk-serverless-cluster-from-snapshot@0.0.45.jsii.tgz",
 )
 
 __all__ = [
